==> fet_5.48.1.orig.tar.bz2: fet-5.48.1/src/interface/modifyconstraintteachersmaxhoursdailyform.h <==
/***************************************************************************
                          modifyconstraintteachersmaxhoursdailyform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTTEACHERSMAXHOURSDAILYFORM_H
#define MODIFYCONSTRAINTTEACHERSMAXHOURSDAILYFORM_H

#include "ui_modifyconstraintteachersmaxhoursdailyform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ModifyConstraintTeachersMaxHoursDailyForm : public QDialog, Ui::ModifyConstraintTeachersMaxHoursDailyForm_template  {
	Q_OBJECT
public:
	ConstraintTeachersMaxHoursDaily* _ctr;

	ModifyConstraintTeachersMaxHoursDailyForm(QWidget* parent, ConstraintTeachersMaxHoursDaily* ctr);
	~ModifyConstraintTeachersMaxHoursDailyForm();

	void updateMaxHoursSpinBox();

public slots:
	void ok();
	void cancel();
};

#endif

==> fet_6.8.5.orig.tar.bz2: fet-6.8.5/src/interface/modifyconstraintteachersmaxhoursdailyform.h <==
/***************************************************************************
                          modifyconstraintteachersmaxhoursdailyform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Liviu Lalescu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTTEACHERSMAXHOURSDAILYFORM_H
#define MODIFYCONSTRAINTTEACHERSMAXHOURSDAILYFORM_H

#include "ui_modifyconstraintteachersmaxhoursdailyform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ModifyConstraintTeachersMaxHoursDailyForm : public QDialog, Ui::ModifyConstraintTeachersMaxHoursDailyForm_template  {
	Q_OBJECT
public:
	ConstraintTeachersMaxHoursDaily* _ctr;

	ModifyConstraintTeachersMaxHoursDailyForm(QWidget* parent, ConstraintTeachersMaxHoursDaily* ctr);
	~ModifyConstraintTeachersMaxHoursDailyForm();

	void updateMaxHoursSpinBox();

public slots:
	void ok();
	void cancel();
};

#endif
